@@ -66,6 +66,8 @@ struct _EtApplicationWindowPrivate
     GtkWidget *hpaned;
     GtkWidget *vpaned;
 
+    GdkCursor *cursor;
+
     gboolean is_maximized;
     gint height;
     gint width;
@@ -1470,12 +1472,42 @@ on_run_player_artist (GSimpleAction *action,
     et_browser_run_player_for_artist_list (ET_BROWSER (priv->browser));
 }
 
+static gboolean
+run_audio_player_using_directory (GError **error)
+{
+    GList *l;
+    GList *file_list = NULL;
+    gboolean res;
+
+    for (l = g_list_first (ETCore->ETFileList); l != NULL; l = g_list_next (l))
+    {
+        ET_File *etfile = (ET_File *)l->data;
+        gchar *path = ((File_Name *)etfile->FileNameCur->data)->value;
+        file_list = g_list_prepend (file_list, g_file_new_for_path (path));
+    }
+
+    file_list = g_list_reverse (file_list);
+
+    res = et_run_audio_player (file_list, error);
+
+    g_list_free_full (file_list, g_object_unref);
+
+    return res;
+}
+
 static void
 on_run_player_directory (GSimpleAction *action,
                          GVariant *variant,
                          gpointer user_data)
 {
-    Run_Audio_Player_Using_Directory ();
+    GError *error = NULL;
+
+    if (!run_audio_player_using_directory (&error))
+    {
+        Log_Print (LOG_ERROR, _("Failed to launch program ‘%s’"),
+                   error->message);
+        g_error_free (error);
+    }
 }
 
 static void
@@ -1598,6 +1630,12 @@ et_application_window_dispose (GObject *object)
         priv->search_dialog = NULL;
     }
 
+    if (priv->cursor)
+    {
+        g_object_unref (priv->cursor);
+        priv->cursor = NULL;
+    }
+
     G_OBJECT_CLASS (et_application_window_parent_class)->dispose (object);
 }
 
@@ -1608,7 +1646,8 @@ et_application_window_init (EtApplicationWindow *self)
     GAction *action;
     GtkWindow *window;
     GtkWidget *main_vbox;
-    GtkWidget *hbox, *vbox;
+    GtkWidget *hbox;
+    GtkWidget *grid;
 
     priv = self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
                                                      ET_TYPE_APPLICATION_WINDOW,
@@ -1640,7 +1679,7 @@ et_application_window_init (EtApplicationWindow *self)
     window = GTK_WINDOW (self);
 
     gtk_window_set_icon_name (window, PACKAGE_TARNAME);
-    gtk_window_set_title (window, PACKAGE_NAME);
+    gtk_window_set_title (window, _(PACKAGE_NAME));
 
     g_signal_connect (self, "configure-event",
                       G_CALLBACK (on_configure_event), NULL);
@@ -1695,19 +1734,21 @@ et_application_window_init (EtApplicationWindow *self)
     gtk_paned_pack1 (GTK_PANED (priv->hpaned), priv->browser, TRUE, TRUE);
 
     /* Vertical box for FileArea + TagArea */
-    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-    gtk_paned_pack2 (GTK_PANED (priv->hpaned), vbox, FALSE, FALSE);
+    grid = gtk_grid_new ();
+    gtk_orientable_set_orientation (GTK_ORIENTABLE (grid),
+                                    GTK_ORIENTATION_VERTICAL);
+    gtk_paned_pack2 (GTK_PANED (priv->hpaned), grid, FALSE, FALSE);
 
     /* TODO: Set a sensible default size for both widgets in the paned. */
     gtk_paned_set_position (GTK_PANED (priv->hpaned), 600);
 
     /* File */
     priv->file_area = et_file_area_new ();
-    gtk_box_pack_start (GTK_BOX (vbox), priv->file_area, FALSE, FALSE, 0);
+    gtk_container_add (GTK_CONTAINER (grid), priv->file_area);
 
     /* Tag */
     priv->tag_area = et_tag_area_new ();
-    gtk_box_pack_start (GTK_BOX (vbox), priv->tag_area, FALSE, FALSE, 0);
+    gtk_container_add (GTK_CONTAINER (grid), priv->tag_area);
 
     /* Vertical pane for Browser Area + FileArea + TagArea */
     priv->vpaned = gtk_paned_new (GTK_ORIENTATION_VERTICAL);
@@ -1719,8 +1760,6 @@ et_application_window_init (EtApplicationWindow *self)
     /* Log */
     priv->log_area = et_log_area_new ();
     gtk_paned_pack2 (GTK_PANED (priv->vpaned), priv->log_area, FALSE, TRUE);
-    g_settings_bind (MainSettings, "log-show", priv->log_area, "visible",
-                     G_SETTINGS_BIND_DEFAULT);
 
     /* Horizontal box for Status bar + Progress bar */
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
@@ -1736,6 +1775,11 @@ et_application_window_init (EtApplicationWindow *self)
     gtk_box_pack_end (GTK_BOX (hbox), priv->progress_bar, FALSE, FALSE, 0);
 
     gtk_widget_show_all (GTK_WIDGET (main_vbox));
+
+    /* Bind the setting after the log area has been shown, to avoid
+     * force-enabling the visibility on startup. */
+    g_settings_bind (MainSettings, "log-show", priv->log_area, "visible",
+                     G_SETTINGS_BIND_DEFAULT);
 }
 
 static void
@@ -1942,6 +1986,29 @@ et_application_window_select_dir (EtApplicationWindow *self, const gchar *path)
     et_browser_select_dir (ET_BROWSER (priv->browser), path);
 }
 
+/*
+ * Select a file in the "main list" using the ETFile address of each item.
+ */
+void
+et_application_window_select_file_by_et_file (EtApplicationWindow *self,
+                                              ET_File *ETFile)
+{
+    if (!ETCore->ETFileDisplayedList)
+        return;
+
+    /* Save the current displayed data */
+    ET_Save_File_Data_From_UI (ETCore->ETFileDisplayed);
+
+    /* Display the item */
+    et_application_window_browser_select_file_by_et_file (self, ETFile, TRUE);
+    /* Just to update 'ETFileDisplayedList'. */
+    ET_Displayed_File_List_By_Etfile (ETFile);
+    ET_Display_File_Data_To_UI (ETFile);
+
+    et_application_window_update_actions (self);
+    et_application_window_scan_dialog_update_previews (self);
+}
+
 const gchar *
 et_application_window_get_current_path (EtApplicationWindow *self)
 {
@@ -2342,6 +2409,35 @@ et_application_window_update_actions (EtApplicationWindow *self)
     }
 }
 
+void
+et_application_window_set_busy_cursor (EtApplicationWindow *self)
+{
+    EtApplicationWindowPrivate *priv;
+
+    g_return_if_fail (ET_APPLICATION_WINDOW (self));
+
+    priv = et_application_window_get_instance_private (self);
+
+    if (!priv->cursor)
+    {
+        priv->cursor = gdk_cursor_new_for_display (gdk_window_get_display (gtk_widget_get_window (GTK_WIDGET (self))),
+                                                   GDK_WATCH);
+
+    }
+
+    gdk_window_set_cursor (gtk_widget_get_window (GTK_WIDGET (self)),
+                           priv->cursor);
+}
+
+void
+et_application_window_set_normal_cursor (EtApplicationWindow *self)
+{
+    g_return_if_fail (ET_APPLICATION_WINDOW (self));
+
+    /* Back to standard cursor */
+    gdk_window_set_cursor (gtk_widget_get_window (GTK_WIDGET (self)), NULL);
+}
+
 /*
  * Display controls according the kind of tag... (Hide some controls if not available for a tag type)
  */
