@@ -20,7 +20,10 @@
  *
  */
 
-#include <config.h>
+#include "config.h"
+
+#include "charset.h"
+
 #include <stdlib.h>
 #include <glib.h>
 #include <string.h>
@@ -31,16 +34,15 @@
 #include <langinfo.h>
 #endif
 
-#include "charset.h"
 #include "setting.h"
 #include "log.h"
-
 #include "win32/win32dep.h"
 
-
-/****************
- * Declarations *
- ****************/
+typedef struct
+{
+    const gchar *charset_title;
+    const gchar *charset_name;
+} CharsetInfo;
 
 #define CHARSET_TRANS_ARRAY_LEN ( sizeof(charset_trans_array) / sizeof((charset_trans_array)[0]) )
 static const CharsetInfo charset_trans_array[] = {
@@ -139,12 +141,6 @@ static const CharsetInfo charset_trans_array[] = {
 static GHashTable *encodings;
 
 
-
-/*************
- * Functions *
- *************/
-
-
 /* stolen from gnome-desktop-item.c */
 static gboolean
 check_locale (const char *locale)
@@ -158,7 +154,7 @@ check_locale (const char *locale)
 
 /* stolen from gnome-desktop-item.c */
 G_GNUC_NULL_TERMINATED static void
-insert_locales (GHashTable *encodings, char *enc, ...)
+insert_locales (GHashTable *encodings, const gchar *enc, ...)
 {
     va_list args;
     char *s;
@@ -169,7 +165,9 @@ insert_locales (GHashTable *encodings, char *enc, ...)
         s = va_arg (args, char *);
         if (s == NULL)
             break;
-        g_hash_table_insert (encodings, s, enc);
+        /* A GDestroyNotify is not passed, so casting away the const is
+         * safe, as the key is never freed. */
+        g_hash_table_insert (encodings, s, (gpointer)enc);
     }
     va_end (args);
 }
@@ -179,6 +177,7 @@ insert_locales (GHashTable *encodings, char *enc, ...)
 void
 Charset_Insert_Locales_Init (void)
 {
+    /* FIXME: Use g_hash_table_new_full. */
     encodings = g_hash_table_new (g_str_hash, g_str_equal);
 
     /* "C" is plain ascii */
@@ -508,8 +507,10 @@ filename_to_display (const gchar *string)
         if (!ret)
         {
             gchar *escaped_str = g_strescape(string, NULL);
-            Log_Print(LOG_ERROR,_("The filename '%s' couldn't be converted into UTF-8 (%s)."),
-                        escaped_str, error && error->message ? error->message : _("Invalid UTF-8"));
+            Log_Print (LOG_ERROR,
+                       _("The filename ‘%s’ could not be converted into UTF-8: %s"),
+                        escaped_str,
+                        error && error->message ? error->message : _("Invalid UTF-8"));
             g_clear_error(&error);
 
             ret = escaped_str;
@@ -546,32 +547,44 @@ gchar *filename_from_display (const gchar *string)
         char_encoding = char_encoding+1; // Skip the '.'
     if (char_encoding)
     {
+        EtRenameEncoding enc_option = g_settings_get_enum (MainSettings,
+                                                           "rename-encoding");
         error = NULL;
 
-        if (FILENAME_CHARACTER_SET_OTHER)
+        switch (enc_option)
         {
-            ret = g_convert(string, -1, char_encoding, "UTF-8", NULL, NULL, &error);
-
-        }else if (FILENAME_CHARACTER_SET_APPROXIMATE)
-        {
-            // iconv_open (3):
-            // When the string "//TRANSLIT" is appended to tocode, transliteration
-            // is activated. This means that when a character cannot be represented
-            // in the target character set, it can be approximated through one or
-            // several similarly looking characters.
-            gchar *enc = g_strconcat(char_encoding, "//TRANSLIT", NULL);
-            ret = g_convert(string, -1, enc, "UTF-8", NULL, NULL, &error);
-            g_free(enc);
-
-        }else if (FILENAME_CHARACTER_SET_DISCARD)
-        {
-            // iconv_open (3):
-            // When the string "//IGNORE" is appended to tocode, characters that
-            // cannot be represented in the target character set will be silently
-            // discarded.
-            gchar *enc = g_strconcat(char_encoding, "//IGNORE", NULL);
-            ret = g_convert(string, -1, enc, "UTF-8", NULL, NULL, &error);
-            g_free(enc);
+            case ET_RENAME_ENCODING_TRY_ALTERNATIVE:
+                ret = g_convert (string, -1, char_encoding, "UTF-8", NULL,
+                                 NULL, &error);
+                break;
+            case ET_RENAME_ENCODING_TRANSLITERATE:
+            {
+                /* iconv_open (3):
+                 * When the string "//TRANSLIT" is appended to tocode,
+                 * transliteration is activated. This means that when a
+                 * character cannot be represented in the target character set,
+                 * it can be approximated through one or several similarly
+                 * looking characters.
+                 */
+                gchar *enc = g_strconcat (char_encoding, "//TRANSLIT", NULL);
+                ret = g_convert (string, -1, enc, "UTF-8", NULL, NULL, &error);
+                g_free (enc);
+                break;
+            }
+            case ET_RENAME_ENCODING_IGNORE:
+            {
+                /* iconv_open (3):
+                 * When the string "//IGNORE" is appended to tocode, characters
+                 * that cannot be represented in the target character set will
+                 * be silently discarded.
+                 */
+                gchar *enc = g_strconcat (char_encoding, "//IGNORE", NULL);
+                ret = g_convert (string, -1, enc, "UTF-8", NULL, NULL, &error);
+                g_free (enc);
+                break;
+            }
+            default:
+                g_assert_not_reached ();
         }
     }
 
@@ -607,8 +620,10 @@ gchar *filename_from_display (const gchar *string)
     {
         // Conversion KO!
         gchar *escaped_str = g_strescape(string, NULL);
-        Log_Print(LOG_ERROR,_("The UTF-8 string '%s' couldn't be converted into filename encoding (%s)."),
-                    escaped_str, error && error->message ? error->message : _("Invalid UTF-8"));
+        Log_Print (LOG_ERROR,
+                   _("The UTF-8 string ‘%s’ could not be converted into filename encoding: %s"),
+                    escaped_str,
+                    error && error->message ? error->message : _("Invalid UTF-8"));
         g_clear_error(&error);
 
         ret = escaped_str;
@@ -670,8 +685,10 @@ gchar *Try_To_Validate_Utf8_String (const gchar *string)
         if (!ret)
         {
             gchar *escaped_str = g_strescape(string, NULL);
-            Log_Print(LOG_ERROR,_("The string '%s' couldn't be converted into UTF-8 (%s)."),
-                        escaped_str, error && error->message ? error->message : _("Invalid UTF-8"));
+            Log_Print (LOG_ERROR,
+                       _("The string ‘%s’ could not be converted into UTF-8: %s"),
+                        escaped_str,
+                        error && error->message ? error->message : _("Invalid UTF-8"));
             g_clear_error(&error);
 
             ret = escaped_str;
@@ -683,24 +700,26 @@ gchar *Try_To_Validate_Utf8_String (const gchar *string)
 
 
 
-void Charset_Populate_Combobox (GtkComboBox *combo, gchar *select_charset)
+void
+Charset_Populate_Combobox (GtkComboBox *combo, gint select_charset)
 {
-    guint i;
+    gsize i;
 
-    for (i=0; i<CHARSET_TRANS_ARRAY_LEN; i++)
+    for (i = 0; i < CHARSET_TRANS_ARRAY_LEN; i++)
     {
-        gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _(charset_trans_array[i].charset_title));
+        gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo),
+                                        _(charset_trans_array[i].charset_title));
 
-        if (select_charset && strcmp(charset_trans_array[i].charset_name, select_charset) == 0)
-            gtk_combo_box_set_active(combo, i);
     }
+
+    gtk_combo_box_set_active (combo, select_charset);
 }
 
 
 /*
  * Return charset_name from charset_title
  */
-gchar *
+const gchar *
 Charset_Get_Name_From_Title (const gchar *charset_title)
 {
     guint i;
@@ -718,3 +737,12 @@ Charset_Get_Name_From_Title (const gchar *charset_title)
 
     return NULL;
 }
+
+const gchar *
+et_charset_get_name_from_index (gint index)
+{
+    g_return_val_if_fail (index >= 0 && index <= CHARSET_TRANS_ARRAY_LEN,
+                          NULL);
+
+    return charset_trans_array[index].charset_name;
+}
