@@ -93,27 +93,6 @@ static void Destroy_Quit_Recursion_Function_Window (void);
 static void et_on_quit_recursion_response (GtkDialog *dialog, gint response_id,
                                            gpointer user_data);
 
-/*
- * Select a file in the "main list" using the ETFile adress of each item.
- */
-void Action_Select_Nth_File_By_Etfile (ET_File *ETFile)
-{
-    if (!ETCore->ETFileDisplayedList)
-        return;
-
-    /* Save the current displayed data */
-    ET_Save_File_Data_From_UI(ETCore->ETFileDisplayed);
-
-    /* Display the item */
-    et_application_window_browser_select_file_by_et_file (ET_APPLICATION_WINDOW (MainWindow),
-                                                          ETFile, TRUE);
-    ET_Displayed_File_List_By_Etfile(ETFile); // Just to update 'ETFileDisplayedList'
-    ET_Display_File_Data_To_UI(ETFile);
-
-    et_application_window_update_actions (ET_APPLICATION_WINDOW (MainWindow));
-    et_application_window_scan_dialog_update_previews (ET_APPLICATION_WINDOW (MainWindow));
-}
-
 /*
  * Action when Save button is pressed
  */
@@ -551,6 +530,10 @@ Save_File (ET_File *ETFile, gboolean multiple_files,
                 if (rc != TRUE && !SF_HideMsgbox_Write_Tag)
                 {
                     stop_loop = -1;
+
+                    g_free (basename_cur_utf8);
+                    g_free (basename_new_utf8);
+
                     return stop_loop;
                 }
                 break;
@@ -560,6 +543,10 @@ Save_File (ET_File *ETFile, gboolean multiple_files,
             case GTK_RESPONSE_CANCEL:
             case GTK_RESPONSE_DELETE_EVENT:
                 stop_loop = -1;
+
+                g_free (basename_cur_utf8);
+                g_free (basename_new_utf8);
+
                 return stop_loop;
                 break;
             default:
@@ -714,6 +701,10 @@ Save_File (ET_File *ETFile, gboolean multiple_files,
                 if (!rc && !SF_HideMsgbox_Rename_File)
                 {
                     stop_loop = -1;
+
+                    g_free (basename_cur_utf8);
+                    g_free (basename_new_utf8);
+
                     return stop_loop;
                 }
 
@@ -727,6 +718,10 @@ Save_File (ET_File *ETFile, gboolean multiple_files,
             case GTK_RESPONSE_CANCEL:
             case GTK_RESPONSE_DELETE_EVENT:
                 stop_loop = -1;
+
+                g_free (basename_cur_utf8);
+                g_free (basename_new_utf8);
+
                 return stop_loop;
                 break;
             default:
@@ -1006,7 +1001,7 @@ Read_Directory (const gchar *path_real)
     }
 
     /* Open the window to quit recursion (since 27/04/2007 : not only into recursion mode) */
-    Set_Busy_Cursor();
+    et_application_window_set_busy_cursor (window);
     action = g_action_map_lookup_action (G_ACTION_MAP (MainWindow), "stop");
     g_settings_bind (MainSettings, "browse-subdir", G_SIMPLE_ACTION (action),
                      "enabled", G_SETTINGS_BIND_GET);
@@ -1121,7 +1116,7 @@ Read_Directory (const gchar *path_real)
     et_application_window_progress_set_fraction (window, 0.0);
     et_application_window_status_bar_message (window, msg, FALSE);
     g_free (msg);
-    Set_Unbusy_Cursor();
+    et_application_window_set_normal_cursor (window);
     ReadingDirectory = FALSE;
 
     return TRUE;
