@@ -36,7 +36,6 @@
 #include "vcedit.h"
 #include "et_core.h"
 #include "id3_tag.h"
-#include "log.h"
 #include "misc.h"
 #include "setting.h"
 #include "picture.h"
@@ -356,12 +355,6 @@ flac_tag_read_file_tag (GFile *file,
                             field_value = Try_To_Validate_Utf8_String(field_value_tmp);
                             g_free(field_value_tmp);
                             FileTag->year = field_value;
-                            if (g_utf8_strlen (FileTag->year, -1) > 4)
-                            {
-                                Log_Print (LOG_WARNING,
-                                           _("The year value ‘%s’ seems to be invalid in file ‘%s’. The information will be lost when saving"),
-                                           FileTag->year, filename_utf8);
-                            }
                         }
                     }
                 }
@@ -739,7 +732,8 @@ flac_tag_read_file_tag (GFile *file,
       && FileTag->encoded_by  == NULL
       && FileTag->picture     == NULL)
     {
-        gboolean rc = id3tag_read_file_tag (file, FileTag, NULL);
+        /* Ignore errors. */
+        id3tag_read_file_tag (file, FileTag, NULL);
 
         // If an ID3 tag has been found (and no FLAC tag), we mark the file as
         // unsaved to rewrite a flac tag.
@@ -763,9 +757,6 @@ flac_tag_read_file_tag (GFile *file,
         {
             FileTag->saved = FALSE;
         }
-
-        g_free(filename_utf8);
-        return rc;
     }
 #endif
 
@@ -1011,7 +1002,7 @@ flac_tag_write_file_tag (const ET_File *ETFile,
          ************/
         Flac_Set_Tag (vc_block, "COMPOSER=", FileTag->composer,
                       g_settings_get_boolean (MainSettings,
-                                              "ogg-split-comment"));
+                                              "ogg-split-composer"));
 
         /*******************
          * Original artist *
@@ -1090,15 +1081,19 @@ flac_tag_write_file_tag (const ET_File *ETFile,
                 picture_block->data.picture.height = pic->height;
                 picture_block->data.picture.depth  = 0;
 
-                // Picture data
-                FLAC__metadata_object_picture_set_data(picture_block, (FLAC__byte *)pic->data, (FLAC__uint32) pic->size, TRUE);
+                /* Picture data. */
+                FLAC__metadata_object_picture_set_data (picture_block,
+                                                        (FLAC__byte *)pic->data, (FLAC__uint32) pic->size,
+                                                        TRUE);
                 
-                if (!FLAC__metadata_object_picture_is_legal(picture_block, &violation))
+                if (!FLAC__metadata_object_picture_is_legal (picture_block,
+                                                             &violation))
                 {
-                    Log_Print (LOG_ERROR, _("Picture block is invalid ‘%s’"),
-                               violation);
-                    FLAC__metadata_object_delete(picture_block);
-                }else
+                    g_critical ("Created an invalid picture block: ‘%s’",
+                                violation);
+                    FLAC__metadata_object_delete (picture_block);
+                }
+                else
                 {
                     // Add the block to the the chain (so we don't need to free the block)
                     FLAC__metadata_iterator_insert_block_after(iter, picture_block);
