@@ -37,7 +37,6 @@
 #include "browser.h"
 #include "setting.h"
 #include "misc.h"
-#include "log.h"
 #include "et_core.h"
 #include "charset.h"
 
@@ -227,6 +226,8 @@ id3tag_read_file_tag (GFile *gfile,
     if ((file = id3_file_open (filename, ID3_FILE_MODE_READONLY)) == NULL)
     {
         g_free (filename);
+        g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED, "%s",
+                     _("Error reading tags from file"));
         return FALSE;
     }
 
@@ -236,6 +237,8 @@ id3tag_read_file_tag (GFile *gfile,
     ||   (tag->nframes == 0))
     {
         id3_file_close(file);
+        g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED, "%s",
+                     _("Error reading tags from file"));
         return FALSE;
     }
 
@@ -933,10 +936,16 @@ id3tag_write_file_v24tag (const ET_File *ETFile,
 
         /* Read old v2 tag */
         if ((file = id3_file_open(filename, ID3_FILE_MODE_READWRITE)) == NULL)
+        {
+            g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED, "%s",
+                         _("Error reading tags from file"));
             return FALSE;
+        }
 
         if ((tmptag = id3_file_tag(file)) == NULL)
         {
+            g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED, "%s",
+                         _("Error reading tags from file"));
             id3_file_close(file);
             return FALSE;
         }
@@ -961,6 +970,8 @@ id3tag_write_file_v24tag (const ET_File *ETFile,
         {
             if ((v2tag = id3_tag_new()) == NULL)
             {
+                g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED, "%s",
+                             _("Error reading tags from file"));
                 id3_file_close(file);
                 return FALSE;
             }
@@ -998,7 +1009,11 @@ id3tag_write_file_v24tag (const ET_File *ETFile,
     {
         v1tag = id3_tag_new();
         if (!v1tag)
+        {
+            g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED, "%s",
+                         _("Error reading tags from file"));
             return FALSE;
+        }
         
         id3_tag_options(v1tag, ID3_TAG_OPTION_ID3V1, ~0);
     }
