@@ -35,7 +35,6 @@
 #include "ogg_tag.h"
 #include "vcedit.h"
 #include "et_core.h"
-#include "log.h"
 #include "misc.h"
 #include "picture.h"
 #include "setting.h"
@@ -162,16 +161,14 @@ read_guint32_from_byte (guchar *str, gsize start)
 
 /*
  * et_add_file_tags_from_vorbis_comments:
- * @vc: the byte string
- * @FileTag: position to start with
- * @filename_utf8: display filename
+ * @vc: Vorbis comment from which to fill @FileTag
+ * @FileTag: tag to populate from @vc
  *
- * Reads vorbis comments and copies them to file tag.
+ * Reads Vorbis comments and copies them to file tag.
  */
-
 void
-et_add_file_tags_from_vorbis_comments (vorbis_comment *vc, File_Tag *FileTag,
-                                       const gchar *filename_utf8)
+et_add_file_tags_from_vorbis_comments (vorbis_comment *vc,
+                                       File_Tag *FileTag)
 {
     gchar *string = NULL;
     gchar *string1 = NULL;
@@ -285,13 +282,6 @@ et_add_file_tags_from_vorbis_comments (vorbis_comment *vc, File_Tag *FileTag,
     if ( (string = vorbis_comment_query(vc,"DATE",0)) != NULL && g_utf8_strlen(string, -1) > 0 )
     {
         FileTag->year = g_strdup(string);
-
-        if (g_utf8_strlen (FileTag->year, -1) > 4)
-        {
-            Log_Print (LOG_WARNING,
-                       _("The year value ‘%s’ seems to be invalid in file ‘%s’. The information will be lost when saving"),
-                       FileTag->year, filename_utf8);
-        }
     }
 
     /*************************
@@ -659,23 +649,17 @@ ogg_tag_read_file_tag (GFile *file,
     g_free (filename);
 
     {
-    // Skip the id3v2 tag
+    /* Check for an unsupported ID3v2 tag. */
     guchar tmp_id3[4];
-    gulong id3v2size;
-
-    // Check if there is an ID3v2 tag...
-    if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET, NULL, error))
-    {
-        goto err;
-    }
 
     if (g_input_stream_read (G_INPUT_STREAM (istream), tmp_id3, 4, NULL,
                              error) == 4)
     {
-        // Calculate ID3v2 length
-        if (tmp_id3[0] == 'I' && tmp_id3[1] == 'D' && tmp_id3[2] == '3' && tmp_id3[3] < 0xFF)
+        /* Calculate ID3v2 length. */
+        if (tmp_id3[0] == 'I' && tmp_id3[1] == 'D' && tmp_id3[2] == '3'
+            && tmp_id3[3] < 0xFF)
         {
-            // id3v2 tag skipeer $49 44 33 yy yy xx zz zz zz zz [zz size]
+            /* ID3v2 tag skipper $49 44 33 yy yy xx zz zz zz zz [zz size]. */
             /* Size is 6-9 position */
             if (!g_seekable_seek (G_SEEKABLE (istream), 2, G_SEEK_CUR,
                                   NULL, error))
@@ -686,35 +670,20 @@ ogg_tag_read_file_tag (GFile *file,
             if (g_input_stream_read (G_INPUT_STREAM (istream), tmp_id3, 4,
                                      NULL, error) == 4)
             {
-                id3v2size = 10 + ( (long)(tmp_id3[3])        | ((long)(tmp_id3[2]) << 7)
-                                | ((long)(tmp_id3[1]) << 14) | ((long)(tmp_id3[0]) << 21) );
+                gchar *path;
 
-                if (!g_seekable_seek (G_SEEKABLE (istream), id3v2size,
-                                      G_SEEK_SET, NULL, error))
-                {
-                    goto err;
-                }
+                path = g_file_get_path (file);
+                g_debug ("Ogg file '%s' contains an ID3v2 tag", path);
+                g_free (path);
 
-                Log_Print (LOG_ERROR,
-                           _("The Ogg Vorbis file ‘%s’ contains an ID3v2 tag"),
-                           filename_utf8);
+                /* Mark the file as modified, so that the ID3 tag is removed
+                 * upon saving. */
+                FileTag->saved = FALSE;
             }
-            else if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET,
-                                       NULL, error))
-            {
-                goto err;
-            }
-
         }
-        else if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET,
-                                   NULL, error))
-        {
-            goto err;
-        }
-
     }
-    else if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET,
-                               NULL, error))
+
+    if (error && *error != NULL)
     {
         goto err;
     }
@@ -744,8 +713,7 @@ ogg_tag_read_file_tag (GFile *file,
             g_print("%s -> Ogg vc:'%s'\n",g_path_get_basename(filename),vc->user_comments[i]);
     }*/
 
-    et_add_file_tags_from_vorbis_comments (vcedit_comments(state), FileTag,
-                                           filename_utf8);
+    et_add_file_tags_from_vorbis_comments (vcedit_comments(state), FileTag);
     vcedit_clear(state);
     g_free (filename_utf8);
 
@@ -754,7 +722,6 @@ ogg_tag_read_file_tag (GFile *file,
 err:
     g_assert (error == NULL || *error != NULL);
     g_object_unref (istream);
-    g_object_unref (istream);
     g_free (filename_utf8);
     return FALSE;
 }
@@ -822,9 +789,7 @@ ogg_tag_write_file_tag (const ET_File *ETFile,
 {
     const File_Tag *FileTag;
     const gchar *filename;
-    const gchar *filename_utf8;
     GFile           *file;
-    GFileInputStream *istream;
     vcedit_state   *state;
     vorbis_comment *vc;
     gchar          *string;
@@ -836,86 +801,8 @@ ogg_tag_write_file_tag (const ET_File *ETFile,
 
     FileTag       = (File_Tag *)ETFile->FileTag->data;
     filename      = ((File_Name *)ETFile->FileNameCur->data)->value;
-    filename_utf8 = ((File_Name *)ETFile->FileNameCur->data)->value_utf8;
 
     file = g_file_new_for_path (filename);
-    istream = g_file_read (file, NULL, error);
-
-    if (!istream)
-    {
-        g_object_unref (file);
-        return FALSE;
-    }
-
-    {
-    // Skip the id3v2 tag
-    gsize bytes_read;
-    guchar tmp_id3[4];
-    gulong id3v2size;
-
-    // Check if there is an ID3v2 tag...
-    if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET, NULL, error))
-    {
-        goto err;
-    }
-
-    if (g_input_stream_read_all (G_INPUT_STREAM (istream), tmp_id3, 4,
-                                 &bytes_read, NULL, error))
-    {
-        // Calculate ID3v2 length
-        if (tmp_id3[0] == 'I' && tmp_id3[1] == 'D' && tmp_id3[2] == '3' && tmp_id3[3] < 0xFF)
-        {
-            // id3v2 tag skipeer $49 44 33 yy yy xx zz zz zz zz [zz size]
-            /* Size is 6-9 position */
-            if (!g_seekable_seek (G_SEEKABLE (istream), 2, G_SEEK_CUR,
-                                  NULL, error))
-            {
-                goto err;
-            }
-
-            if (g_input_stream_read_all (G_INPUT_STREAM (istream), tmp_id3, 4,
-                                         &bytes_read, NULL, error))
-            {
-                id3v2size = 10 + ( (long)(tmp_id3[3])        | ((long)(tmp_id3[2]) << 7)
-                                | ((long)(tmp_id3[1]) << 14) | ((long)(tmp_id3[0]) << 21) );
-
-                if (!g_seekable_seek (G_SEEKABLE (istream), id3v2size,
-                                      G_SEEK_SET, NULL, error))
-                {
-                    goto err;
-                }
-
-                Log_Print (LOG_ERROR,
-                           _("The Ogg Vorbis file ‘%s’ contains an ID3v2 tag"),
-                           filename_utf8);
-            }
-            else
-            {
-                g_debug ("Only %" G_GSIZE_FORMAT " bytes out of 4 bytes of "
-                         "data were read", bytes_read);
-                goto err;
-            }
-
-        }
-        else if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET,
-                                   NULL, error))
-        {
-            goto err;
-        }
-
-    }
-    else
-    {
-        g_debug ("Only %" G_GSIZE_FORMAT " bytes out of 4 bytes of data were "
-                 "read", bytes_read);
-        goto err;
-    }
-
-    }
-
-    g_assert (error == NULL || *error == NULL);
-
-    g_object_unref (istream);
 
     state = vcedit_new_state();    // Allocate memory for 'state'
 
@@ -1046,8 +933,7 @@ ogg_tag_write_file_tag (const ET_File *ETFile,
                 if (!gdk_pixbuf_loader_write (loader, pic->data, pic->size,
                                               &error))
                 {
-                    Log_Print (LOG_ERROR, _("Error parsing image data ‘%s’"),
-                               error->message);
+                    g_debug ("Error parsing image data: %s", error->message);
                     g_error_free (error);
                     g_object_unref (loader);
                     continue;
@@ -1060,9 +946,8 @@ ogg_tag_write_file_tag (const ET_File *ETFile,
 
                     if (!gdk_pixbuf_loader_close (loader, &error))
                     {
-                        Log_Print (LOG_ERROR,
-                                   _("Error parsing image data ‘%s’"),
-                                   error->message);
+                        g_debug ("Error parsing image data: %s",
+                                 error->message);
                         g_error_free (error);
                         g_object_unref (loader);
                         continue;
@@ -1181,11 +1066,5 @@ ogg_tag_write_file_tag (const ET_File *ETFile,
 
     g_assert (error == NULL || *error == NULL);
     return TRUE;
-    
-err:
-    g_assert (error == NULL || *error != NULL);
-    g_object_unref (istream);
-    g_object_unref (file);
-    return FALSE;
 }
 #endif /* ENABLE_OGG */
